@@ -4,8 +4,6 @@
 #
 #   n.b.
 #     - No replacement methods available for op.type.
-#     - similar to operator.tools::operator.type which is applied directly to
-#       the operator
 # -----------------------------------------------------------------------------
 
 # OP.TYPE
@@ -13,8 +11,9 @@ setGeneric( 'op.type', function(x) standardGeneric( 'op.type' ) )
 
 
 # SINGULAR METHODS
-setMethod(  'op.type', 'call' , function (x) operator.type( (op(x) )  ) )
-setMethod(  'op.type', 'formula' , function (x) operator.type( op(x) ) )
+setMethod( 'op.type', 'call' , function(x) operator.type( (op(x) )  ) )
+setMethod( 'op.type', 'formula' , function(x) operator.type( op(x) ) )
+setMethod( 'op.type', '<-', function(x) operator.type( op(x) ) ) 
 
 
 # PLURAL METHODS
