@@ -1,12 +1,12 @@
-# -----------------------------------------------------------------------------O
+# -----------------------------------------------------------------------------
 # FUNCTION : terms.call 
 #   a terms method for call and expression objects.
-# -----------------------------------------------------------------------------O
+# -----------------------------------------------------------------------------
 
 terms.call <- function( x , ...  ) 
 {
 
-  if( deparse( x[[1]] ) %in% c( relational.operators ) ) 
+  if( deparse( x[[1]] ) %in% c( operators() ) ) 
   { 
     all.vars(x) 
   } else {  
